@@ -1,5 +1,5 @@
 from TDhelper.generic.transformationType import transformation
-from FieldType import *
+from TDhelper.document.excel.FieldType import *
 from types import FunctionType, MethodType, ModuleType
 from openpyxl import load_workbook
 import csv
