@@ -1,4 +1,4 @@
-from meta.modelMeta import modelMeta
+from TDhelper.document.excel.meta.modelMeta import modelMeta
 class model(metaclass=modelMeta):
     __excelHandle__= None
     __sheetHandle__= None
